@@ -239,3 +239,25 @@ def search_subdirs(dir_name: str) -> Tuple[List[str], List[str]]:
             sub_dirs.append(os.path.join(path, subdir))
 
     return (result_files, sub_dirs)
+
+
+def write_tar(target_dir: str, file_name: str) -> None:
+    """
+    The write_tar function takes a target directory and an output name as arguments.
+    It then creates a tar file with the given output name, and adds all files in the target directory to it.
+
+    :param target_dir:str: Used to Specify the directory that you want to compress.
+    :param out_name:str: Used to Specify the name of the tar file that will be created.
+    :return: None.
+
+    :doc-author: Julian M. Kleber
+    """
+
+    import tarfile
+
+    tar = tarfile.open(file_name, "w")
+    for root, dir, files in os.walk(target_dir):
+        for file in files:
+            fullpath = os.path.join(root, file)
+            tar.add(fullpath, arcname=file)
+    tar.close()
